@@ -2,7 +2,7 @@
 
 APP='Tanglet'
 BUNDLE="$APP.app"
-VERSION='1.5.2'
+VERSION='1.5.3'
 
 # Remove any previous disk folder or DMG
 echo -n 'Preparing... '
@@ -35,7 +35,7 @@ echo >> "$APP/Read Me.txt"
 echo 'NEWS' >> "$APP/Read Me.txt"
 echo '====' >> "$APP/Read Me.txt"
 echo >> "$APP/Read Me.txt"
-cat NEWS >> "$APP/Read Me.txt"
+cat ChangeLog >> "$APP/Read Me.txt"
 echo 'Done'
 
 # Copy translations
