@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2010, 2011, 2014, 2015 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2010, 2011, 2014, 2015, 2017, 2018 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -177,6 +177,8 @@ Board::Board(QWidget* parent)
 //-----------------------------------------------------------------------------
 
 Board::~Board() {
+	m_generator->cancel();
+
 	QSettings game;
 	if (isFinished()) {
 		// Clear current game
@@ -369,7 +371,7 @@ void Board::gameStarted() {
 	int letter_size = 0;
 	for (const QStringList& die : m_generator->dice(m_size)) {
 		for (const QString& side : die) {
-			letter_size = std::max(letter_size, metrics.width(side));
+			letter_size = std::max(letter_size, metrics.boundingRect(side).width());
 		}
 	}
 	int cell_size = std::max(metrics.height(), letter_size) + 10;
@@ -474,8 +476,8 @@ void Board::clearGuess() {
 	clearHighlight();
 	updateClickableStatus();
 	m_guess->clear();
-	m_found->clearSelection();
-	m_missed->clearSelection();
+	m_found->setCurrentItem(nullptr);
+	m_missed->setCurrentItem(nullptr);
 	m_guess->setFocus();
 	updateButtons();
 }
@@ -515,8 +517,8 @@ void Board::guess() {
 
 			m_counts->findWord(text);
 		}
-		m_found->scrollToItem(item, QAbstractItemView::PositionAtCenter);
-		m_found->clearSelection();
+		m_found->scrollToItem(item);
+		m_found->setCurrentItem(nullptr);
 
 		// Clear guess
 		clearGuess();
@@ -541,13 +543,15 @@ void Board::guessChanged() {
 	m_valid = true;
 	m_wrong = false;
 	clearHighlight();
-	m_found->clearSelection();
+	m_found->setCurrentItem(nullptr);
 
 	QString word = m_guess->text().trimmed().toUpper();
 	if (!word.isEmpty()) {
 		int pos = m_guess->cursorPosition();
 		m_guess->setText(word);
 		m_guess->setCursorPosition(pos);
+		QTreeWidgetItem* item = m_found->findItems(word, Qt::MatchStartsWith, 2).value(0);
+		m_found->scrollToItem(item, QAbstractItemView::PositionAtTop);
 
 		Trie trie(word);
 		Solver solver(trie, m_size, 0);
@@ -662,6 +666,8 @@ void Board::letterClicked(Letter* letter) {
 		QString word = m_guess->text().trimmed().toUpper();
 		word.append(letter->text().toUpper());
 		m_guess->setText(word);
+		QTreeWidgetItem* item = m_found->findItems(word, Qt::MatchStartsWith, 2).value(0);
+		m_found->scrollToItem(item, QAbstractItemView::PositionAtTop);
 
 		m_wrong = false;
 		m_positions.append(letter->position());
@@ -774,9 +780,9 @@ void Board::selectGuess() {
 	QTreeWidgetItem* item = m_found->findItems(m_guess->text(), Qt::MatchExactly, 0).value(0);
 	if (item != 0) {
 		m_found->setCurrentItem(item);
-		m_found->scrollToItem(item, QAbstractItemView::PositionAtCenter);
+		m_found->scrollToItem(item);
 	} else {
-		m_found->clearSelection();
+		m_found->setCurrentItem(nullptr);
 	}
 }
 
@@ -875,13 +881,14 @@ void Board::showMaximumWords() {
 	for (const QString& word : m_solutions.keys()) {
 		scores.append(Solver::score(word));
 	}
-	qSort(scores.begin(), scores.end(), qGreater<int>());
+	std::sort(scores.begin(), scores.end(), std::greater<int>());
 	scores = scores.mid(0, 30);
 
 	QLabel* message = new QLabel(tr("The maximum score was calculated from the following thirty words:"), this);
 	message->setWordWrap(true);
 
 	WordTree* words = new WordTree(this);
+	words->setTrie(m_generator->trie());
 	words->setDictionary(m_generator->dictionary());
 	QList<QTreeWidget*> trees = QList<QTreeWidget*>() << m_found << m_missed;
 	for (QTreeWidget* tree : trees) {
